#include <proto.h>

#include "gtbdrman.h"
#include "gtapp.h"
#include "gterror.h"
#include "gtresname.h"
#include "gtcommon.h"

/************************************************************************\
*
* GtBdrMan class.
*
* $Ident: This file is part of the 'Gt-library' 1.0.0 $
* $Copyright: (C) 1997 by Gran Gustafsson $
*
\************************************************************************/

/************************************************************************\
*
* Check if class is (sub)class of named class.
*
\************************************************************************/
sbool GtBdrMan::IsSubClassOf(char *cn)
{
	if(strcmp(cn,"GtBdrMan")==0)
		return(TRUE);
	else
		return(GtManager::IsSubClassOf(cn));
}

/************************************************************************\
*
* Set child layout information tags.
*
\************************************************************************/
sbool GtBdrMan::SetLInfo(GtWidget *o,GtTag *tgs)
{
	GtTag *t;
	sbool res;
	GtWListBdr *li;
	word tmp;
	
	res=GtManager::SetLInfo(o,tgs);
	li=(GtWListBdr *)o->GetLInfo();
	while((t=GtNextTag(&tgs)))
	{
		switch(t->tag)
		{
			case GT_BAll:
				tmp=t->d.val;
				li->bleft=tmp;
				li->bright=tmp;
				li->btop=tmp;
				li->bbot=tmp;
				res=TRUE;
				break;
			case GT_BLeft:
				li->bleft=t->d.val;
				res=TRUE;
				break;
			case GT_BRight:
				li->bright=t->d.val;
				res=TRUE;
				break;
			case GT_BTop:
				li->btop=t->d.val;
				res=TRUE;
				break;
			case GT_BBot:
				li->bbot=t->d.val;
				res=TRUE;
				break;
			case GT_MinXSize:
				li->minxs=t->d.val;
				res=TRUE;
				break;
			case GT_MinYSize:
				li->minys=t->d.val;
				res=TRUE;
				break;
			case GT_MaxXSize:
				li->maxxs=t->d.val;
				res=TRUE;
				break;
			case GT_MaxYSize:
				li->maxys=t->d.val;
				res=TRUE;
				break;
		}
	}
	if(res)
	{
		li->minxs=GTMAX(li->minxs,1);
		li->minys=GTMAX(li->minys,1);
		li->maxxs=GTMAX(li->minxs,GTMIN(li->maxxs,GTS_MAX));
		li->maxys=GTMAX(li->minys,GTMIN(li->maxys,GTS_MAX));
	}
	return(res);
}

/************************************************************************\
*
* Get child layout information tags.
*
\************************************************************************/
void GtBdrMan::GetLInfo(GtWidget *o,GtTag *tgs)
{
	GtTag *t;
	GtWListBdr *li;
	long *ptr;
	
	GtManager::GetLInfo(o,tgs);
	li=(GtWListBdr *)o->GetLInfo();
	while((t=GtNextTag(&tgs)))
	{
		if(!(ptr=(long *)t->d.ptr))
			continue;
		switch(t->tag)
		{
			case GT_BLeft:
				*ptr=li->bleft;
				break;
			case GT_BRight:
				*ptr=li->bright;
				break;
			case GT_BTop:
				*ptr=li->btop;
				break;
			case GT_BBot:
				*ptr=li->bbot;
				break;
			case GT_MinXSize:
				*ptr=li->minxs;
				break;
			case GT_MinYSize:
				*ptr=li->minys;
				break;
			case GT_MaxXSize:
				*ptr=li->maxxs;
				break;
			case GT_MaxYSize:
				*ptr=li->maxys;
				break;
		}
	}
}

/************************************************************************\
*
* Relayout if child request move or resize.
*
\************************************************************************/
void GtBdrMan::MoveSizeReq(GtWidget *o,word xp,word yp,word xs,word ys)
{
	o=o;
	xp=xp;
	yp=yp;
	xs=xs;
	ys=ys;
	this->Relayout();
}

/************************************************************************\
*
* Create child layout information.
*
\************************************************************************/
GtWList *GtBdrMan::MakeWList(GtWidget *o,int sz)
{
	GtWListBdr *li;
	word tmp=0;
	
	li=(GtWListBdr *)GtManager::MakeWList(o,
		sz+sizeof(GtWListBdr)-sizeof(GtWList));
	if(!li)
		return(NULL);
	li->minxs=1;
	li->minys=1;
	li->maxxs=GTS_MAX;
	li->maxys=GTS_MAX;
	if(app->GetRes(o,GTR_BALL,GTRT_WORD,&tmp))
	{
		li->bleft=tmp;
		li->bright=tmp;
		li->btop=tmp;
		li->bbot=tmp;
	}
	app->GetRes(o,GTR_BLEFT,GTRT_WORD,&li->bleft);
	app->GetRes(o,GTR_BRIGHT,GTRT_WORD,&li->bright);
	app->GetRes(o,GTR_BTOP,GTRT_WORD,&li->btop);
	app->GetRes(o,GTR_BBOT,GTRT_WORD,&li->bbot);
	app->GetRes(o,GTR_MINXS,GTRT_WORD,&li->minxs);
	app->GetRes(o,GTR_MINYS,GTRT_WORD,&li->minys);
	app->GetRes(o,GTR_MAXXS,GTRT_WORD,&li->maxxs);
	app->GetRes(o,GTR_MAXYS,GTRT_WORD,&li->maxys);
	return((GtWList *)li);
}
